==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/GetSkusNestedResourceTypeFirstPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property nestedResourceTypeFirst The first child resource type.
 * @property providerNamespace The name of the resource provider hosted within ProviderHub.
 * @property resourceType The resource type.
 * @property sku The SKU.
 */
public data class GetSkusNestedResourceTypeFirstPlainArgs(
    public val nestedResourceTypeFirst: String,
    public val providerNamespace: String,
    public val resourceType: String,
    public val sku: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs =
        com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs.builder()
            .nestedResourceTypeFirst(nestedResourceTypeFirst.let({ args0 -> args0 }))
            .providerNamespace(providerNamespace.let({ args0 -> args0 }))
            .resourceType(resourceType.let({ args0 -> args0 }))
            .sku(sku.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSkusNestedResourceTypeFirstPlainArgs].
 */
@PulumiTagMarker
public class GetSkusNestedResourceTypeFirstPlainArgsBuilder internal constructor() {
    private var nestedResourceTypeFirst: String? = null

    private var providerNamespace: String? = null

    private var resourceType: String? = null

    private var sku: String? = null

    /**
     * @param value The first child resource type.
     */
    @JvmName("xmfvvygfurcbtuwl")
    public suspend fun nestedResourceTypeFirst(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.nestedResourceTypeFirst = mapped
    }

    /**
     * @param value The name of the resource provider hosted within ProviderHub.
     */
    @JvmName("swslcqamsichpufg")
    public suspend fun providerNamespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.providerNamespace = mapped
    }

    /**
     * @param value The resource type.
     */
    @JvmName("bvvrxkkmxyuvlqnp")
    public suspend fun resourceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceType = mapped
    }

    /**
     * @param value The SKU.
     */
    @JvmName("hlaimeuhlwxgriye")
    public suspend fun sku(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sku = mapped
    }

    internal fun build(): GetSkusNestedResourceTypeFirstPlainArgs =
        GetSkusNestedResourceTypeFirstPlainArgs(
            nestedResourceTypeFirst = nestedResourceTypeFirst ?: throw
                PulumiNullFieldException("nestedResourceTypeFirst"),
            providerNamespace = providerNamespace ?: throw PulumiNullFieldException("providerNamespace"),
            resourceType = resourceType ?: throw PulumiNullFieldException("resourceType"),
            sku = sku ?: throw PulumiNullFieldException("sku"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/GetSkusNestedResourceTypeFirstPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property nestedResourceTypeFirst The first child resource type.
 * @property providerNamespace The name of the resource provider hosted within ProviderHub.
 * @property resourceType The resource type.
 * @property sku The SKU.
 */
public data class GetSkusNestedResourceTypeFirstPlainArgs(
    public val nestedResourceTypeFirst: String,
    public val providerNamespace: String,
    public val resourceType: String,
    public val sku: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs =
        com.pulumi.azurenative.providerhub.inputs.GetSkusNestedResourceTypeFirstPlainArgs.builder()
            .nestedResourceTypeFirst(nestedResourceTypeFirst.let({ args0 -> args0 }))
            .providerNamespace(providerNamespace.let({ args0 -> args0 }))
            .resourceType(resourceType.let({ args0 -> args0 }))
            .sku(sku.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSkusNestedResourceTypeFirstPlainArgs].
 */
@PulumiTagMarker
public class GetSkusNestedResourceTypeFirstPlainArgsBuilder internal constructor() {
    private var nestedResourceTypeFirst: String? = null

    private var providerNamespace: String? = null

    private var resourceType: String? = null

    private var sku: String? = null

    /**
     * @param value The first child resource type.
     */
    @JvmName("dmmmjspultnyyxko")
    public suspend fun nestedResourceTypeFirst(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.nestedResourceTypeFirst = mapped
    }

    /**
     * @param value The name of the resource provider hosted within ProviderHub.
     */
    @JvmName("qjqpjijrkgwlycmg")
    public suspend fun providerNamespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.providerNamespace = mapped
    }

    /**
     * @param value The resource type.
     */
    @JvmName("ltftjacqnrygpeeo")
    public suspend fun resourceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceType = mapped
    }

    /**
     * @param value The SKU.
     */
    @JvmName("cpnpjafdqqboxlfi")
    public suspend fun sku(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sku = mapped
    }

    internal fun build(): GetSkusNestedResourceTypeFirstPlainArgs =
        GetSkusNestedResourceTypeFirstPlainArgs(
            nestedResourceTypeFirst = nestedResourceTypeFirst ?: throw
                PulumiNullFieldException("nestedResourceTypeFirst"),
            providerNamespace = providerNamespace ?: throw PulumiNullFieldException("providerNamespace"),
            resourceType = resourceType ?: throw PulumiNullFieldException("resourceType"),
            sku = sku ?: throw PulumiNullFieldException("sku"),
        )
}
